/*******************************************************************************
*
*  DSPMain.dsp
*
*  (c) 2002-2004 ethan bordeaux
*  syndevkit@dspmusic.org
*
*
*******************************************************************************/


.module                                     modDSPMain;

#include ".\chicsys\hdr\codechdr.h"
#include ".\gen_fx\hdr\GenFX.h"
#include ".\chicsys\hdr\chicsym.h"
#include ".\comsys\hdr\comsym.h"

.ENTRY      main;
.ENTRY      FRL;

/******************************************************************************
 *  Main Program
 ******************************************************************************/

main:
    reset FL1;

	call InitMemory;
   	call InitSport0;
   	call CBRC;
   	call InitSystemRegs;
   	
   	call InitAD1885;
    call InitOutBuffs;
      
    /* crazy init thing for WTGen2/LFO3 - WT[0] must equal WT[128] */
    AR = DM(a_WTSine + 0);
    DM(a_WTSine + 128) = AR;
    AR = DM(a_WTSaw + 0);
    DM(a_WTSaw + 128) = AR;
    AR = DM(a_WTSq + 0);
    DM(a_WTSq + 128) = AR;
    AR = DM(a_WTTri + 0);
    DM(a_WTTri + 128) = AR;

    IMASK = IRQE_IRQ | SPORT0TX_IRQ | SPORT0RX_IRQ;
    ena ints;

    !call GetRandSeed;

/* 
 *  count number of songs to be played by analyzing number of instructions
 *  between CurrSongJT and first pointer initialization.  the 16 MSBs of a 
 *  jump instruction should always be less than 0x2000.
 */
 
    AF = pass 0;
    I5 = ^CurrSongJT;

CountSongs:
    AR = PM(I5, M7);
    AR = AR - 0x2000;
    if GT jump EndSongCount;
    AF = AF + 1;
    jump CountSongs;

EndSongCount:
    AR = pass AF;
    DM(v_NumSongs) = AR;
 
/*
 *  when a song ends, it jump back to FRL.  SongPtrs checks the currently
 *  selected song, updates the 5 pointers into different functions, and updates
 *  v_CurrSong such that it will pick the next song on the list.
 */

FRL:
    call SongPtrs;

    /* fill random number array, set I, L reg that are forever mapped here */
    call FillRandLUT;
    I6 = ^a_RandLUT;
    L6 = %a_RandLUT;

    /* init all output buffers along with common GenFX buffers */
    call InitOutBuffs;
    
    /* init routines specific to a particular song */
    I5 = DM(InitGMParamsPtr);
    call (I5);
    
/*
 *  fill an audio buffer with 128 words of data.  once complete, wait in idle
 *  until interrupt occurs.
 */

FillAudioBuffer:
    I5 = DM(SetFABCNTRPtr);
    call (I5);

    CNTR = AR;
    do FAB until CE;
      
      /* set all function and output ptrs and output before 1st func call */
      call GenFXPtrInits;

      /* call all signal generators and modifiers */
      I5 = DM(GenFXPtr);
      call (I5);

      /* reset a_GenData ptr (array where gen/fx written) */
      AR = ^a_GenData;
      DM(p_GenData) = AR;
   
      /* call mixing/write to output array function, code in GenFX.dsp */
      I5 = DM(MixerProcPtr);
      call (I5);

FAB:  nop;

/*
 *  after all OUTBUFFLEN samples are generated, wait in idle loop until the
 *  other buffer is cleaned out.  if this check didn't exist,  the
 *  data calculation buffer could fill too fast and the transmission buffer
 *  would be accessed before all the data was properly sent to the serial port.
 */

BufferNotEmpty:
    idle;
	AR = DM(b_FillNewBuffer);
	AR = pass AR;
	if EQ jump BufferNotEmpty;              /* was all data read from buffer? */
	
	/* reset FillNewBuffer indicator */
	DM(b_FillNewBuffer) = M0;
	
	/* swap output array.  note this is opposite polarity of that in gmISRs! */
    AX0 = ^a_LOutBuff0;
    AX1 = ^a_ROutBuff0;
    AR = DM(v_TXBuff0or1);
    AR = pass AR;
    if NE jump SetBufferPtr;
    AX0 = ^a_LOutBuff1;
    AX1 = ^a_ROutBuff1;
    
SetBufferPtr:
    DM(p_LOutBuff) = AX0;
    DM(p_RoutBuff) = AX1;

    /* call sequencer and SongCTRL and MemEnvs and other fun stuff */
    I5 = DM(ModFuncsPtr);
    call (I5);

    /* check for next song indicator, set v_CurrSong appropriately */
    call AdvanceSong;
                
    /* shuffle data in random array */
    call ReRandomize;

    /* determine if we should exit main processing loop or keep making data */
    AR = DM(b_EndSong);
    AR = pass AR;
    if EQ jump FillAudioBuffer;

/*
 *  song over, rts to return to monitor code
 */
  
EndOfSong:
    rts;
    !jump FillAudioBuffer;
                                                                
.ENDMOD;


