/******************************************************************************
*
*  GenFXIni.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  initialization of all generators, fx, envelopes and sequencer.  called at
*  the beginning of the song before audio output.  extensive post processing
*  and analysis occurs on this function, so follow the guidelines on usage as
*  outlined in the documentation.
*
******************************************************************************/

.MODULE                                     modGenFXIni_00;

/*
 *  include files for all functions
 */
 

#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"
#include    "ex3.h"

/*
 *  external variables and functions
 */

/*
 *  entry points
 */

.ENTRY      InitGMParams_00;
.ENTRY      EndInitGMParams_00;

InitGMParams_00:
    /* insert generators and fx initializations here */
    SETPTR(a_WTGen2);
    INIT_WTGEN2(0, ^a_WTSine);
    INIT_WTGEN2(0, ^a_WTSine);
    INIT_WTGEN2(0, ^a_WTSaw);
    
    SETPTR(a_KSGen);
    INIT_KSGEN(0x0001, ^a_KSBuff0, 0x1ff, 0x0000, 0x3c00);
    INIT_KSGEN(0x0001, ^a_KSBuff1, 0x1ff, 0x0000, 0x3c00);
    INIT_KSGEN(0x0000, ^a_KSBuff2, 0x3f, 0x0000, 0x5000);
    INIT_KSGEN(0x0000, ^a_KSBuff3, 0x3f, 0x0000, 0x5000);

    SETPTR(a_SVFFX);
    INIT_SVFFX(0x7000, 0x2000, 0x2000, SVFFX_HIGHOUT);
    INIT_SVFFX(0x7000, 0x2000, 0x2000, SVFFX_HIGHOUT);
    
    SETPTR(a_ExpDecayEnv);
    INIT_EXPDECAYENV(4, 0x7ff0, 0x4800);        ! bd0
    INIT_EXPDECAYENV(12, 0x7ff0, 0x3800);       ! bd1
    INIT_EXPDECAYENV(12, 0x7f00, 0x4000);       ! rhythmsaw
    INIT_EXPDECAYENV(16, 0x7ff0, 0x2000);       ! hh1
    INIT_EXPDECAYENV(16, 0x7ff0, 0x6000);       ! hh1
    INIT_EXPDECAYENV(16, 0x7ff0, 0x2000);       ! hh2
    INIT_EXPDECAYENV(16, 0x7ff0, 0x6000);       ! hh2
    
    SETPTR(a_MemEnv2);
    INIT_MEMENV2(^a_WTGen2+(0*WTGEN2_VARS)+WTGEN2_FREQ, 700, 20, 0x1000, 0x0800, 0x0400, 1, 0x6400, 1, 0x7c00, 1, 0x7f00, 1, 0x7f80);
    INIT_MEMENV2(^a_WTGen2+(1*WTGEN2_VARS)+WTGEN2_FREQ, 400, 20, 0x1000, 0x0800, 0x0400, 1, 0x6400, 1, 0x7c00, 1, 0x7f00, 1, 0x7f80);
    
    SETPTR(a_MemEnv3);
    INIT_MEMENV3(^a_WTGen2+(2*WTGEN2_VARS)+WTGEN2_FREQ, 700, 700, 1, 600, 80);
    
    SETPTR(a_ADSRPanEnv);
    INIT_ADSRPANENV(128, 0x0100, 0x7fff, 0x0000, 0, 0x0000, 0x2000);
    INIT_ADSRPANENV(128, 0x0100, 0x7fff, 0x0000, 0, 0x0000, 0x6000);
           
    /* init TrigTrack and VolTrack arrays as needed */    
    
/*
 *  init sequencer array
 *  
 *  param0:  tic period
 *  param1:  swing period (num tics between slow/fast transition)
 *  param2:  swing amount
 *  param3:  sequencer length
 *  param4:  ptr to TrigInit function
 *  param5:  envelope type
 *  param6:  aux function ptr
 *
 */

    SETPTR(a_Seq2);
    modify(I2, M1);                         /* numtrax set by CalcSeq2Tracks */

    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, ADSRENV);
    INIT_SEQ2(21, 0, 0, 32, ADSRENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);
    INIT_SEQ2(21, 0, 0, 32, EXPDECAYENV);

    /* must be called after Seq2 init to set env and num tracks */
    call Seq2PostProc;
    
    /* set v_TicsPerMeasure to length of first sequence */
    SEQ2_SET_MEASURE(0);

    AR = ^InitGMParams_00;
    AX0 = ^EndInitGMParams_00;
    call FillGenFXPtrInits;
    
    /* init ^Env and set length of array of ptrs used in GenFXPtrInits */
    call GenFXIniPostProc;                  /* do not remove! */
    
EndInitGMParams_00:
    rts;

.ENDMOD;
