/******************************************************************************
*
*  SongCTRL.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  function for modifying parameters on a measure by measure basis.  execution
*  rate determined by v_TicsPerMeasure (set in GenFXIni.dsp by macros).
*
******************************************************************************/

.MODULE                                     modSongCTRL_00;

/*
 *  include files for all functions
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"
#include    "exp2_3.h"

/*
 *  external variables and functions
 */

/*
 *  entry points
 */

.ENTRY      SongCTRL_00;
.ENTRY      Measure_JT;
.ENTRY      EndMeasure_JT;

SongCTRL_00:
    AR = DM(v_TicCNTR);
    AR = AR + 1;
    DM(v_TicCNTR) = AR;
    AY0 = DM(v_TicsPerMeasure);
    AR = AR - AY0;
    if LT rts;
    
    DM(v_TicCNTR) = M0;

/*
 *  note!  this initialization used to be in InitFunc.dsp.  however, to make
 *  this function work with multiple tracks in a single executable, Measure_JT
 *  and EndMeasure_JT would need to be abstracted and inited in SongPtrs.dsp.
 *  to try and simplify and reduce the number of initializations that occur in
 *  that function, these variables were made local and it is continually
 *  re-inited here.  note that this code runs in the krate loop so performance
 *  is not a concern.
 */

SetMeasuresPerSong:
    AX0 = ^EndMeasure_JT;
    AY0 = ^Measure_JT;
    AR = AX0 - AY0;
    DM(v_MeasuresPerSong) = AR;
    
    I5 = ^Measure_JT;
    M5 = DM(v_CurrMeasure);
    modify(I5, M5);
    jump (I5);
    
/*
 *  insert JT of operations to perform at the start of every new measure
 */
    
Measure_JT:
    jump Measure0;                              ! 1st bd, snare, 1st fm
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure4;                              ! hihat, more bd
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure8;                              ! 2nd bd
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure12;                             ! revnoise and 2nd fm
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure20;                             ! bass, 8 measure filter mod
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure28;                             ! pad
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    ! breakdown, remove lots of stuff, bring in 2 leads, change lead freq
    jump Measure32;
    jump DoNothing;
    jump Measure34;                             ! 2nd lead, 1st freq
    jump DoNothing;
    
    jump Measure36;                             ! 2nd lead freq
    jump DoNothing;
    jump Measure38;                             ! more pad, mod pad freq
    jump DoNothing;
    
    jump Measure40;                             ! add rhythmsaw
    jump Measure41;                             ! add bd
    jump Measure42;                             ! add hh
    jump Measure43;                             ! new fm patterm
    
    jump Measure44;                             ! kill, fade in bass
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure48;                             ! nothing, everything in
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;

    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure56;                             ! new bd pattern
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure60;                             ! new snare pattern
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure64;                             ! fade bd
    jump DoNothing;
    jump Measure66;                             ! fade hh, rhythmsaw
    jump DoNothing;
    
    jump Measure68;                             ! bass
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure76;                             ! fade leads
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump DoNothing;
    jump DoNothing;
    
    jump Measure80;                             ! bd one more time
    jump DoNothing;
    jump DoNothing;
    
    jump Measure82;                             ! hh one more time
    jump DoNothing;
    jump DoNothing;
    
    jump Measure84;                             ! mute all but noise, pad
    jump DoNothing;
    jump DoNothing;
    jump DoNothing;
    
    jump Measure88;                             ! kill all but pad
    jump Measure89;                             ! kill pad
    jump DoNothing;
    jump DoNothing;
    
EndMeasure_JT:

/*
 *  insert all multimeasure operations - for parameters that should be modified
 *  over multiple measures
 */

MultiMeasureCheck:

EndSongCheck:
    AR = DM(v_CurrMeasure);
    AR = AR + 1;
    DM(v_CurrMeasure) = AR;
    AY0 = DM(v_MeasuresPerSong);
    AR = AR - AY0;
    if LT rts;

/*
 *  SongCTRL list is complete.  jumping to EndSong will start the next song
 *  in a multisong environment.  resetting CurrMeasure starts the Measure_JT
 *  loop over again, causing the same song to play indefinitely
 */
    
    !jump EndSong;
    
    DM(v_CurrMeasure) = M0;
    rts;

MultiMeasureMod:
    AR = DM(v_CurrMeasure);   
    AY0 = SR0;       
    NONE = AR - AY0;         
    if LT jump EndMMM;
    AY0 = SR1;
    NONE = AR - AY0;
    if GT jump EndMMM;
    call (I5);
EndMMM:
    rts;

Measure0:
/* SETTRACK(CLEAR, 0, 0,  a--- ---- ---- ----  a--- ---- ---- a---   ---- a--- ---- ----  a--- ---- ---- a---,
            CLEAR, 0, 5,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 6,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 14, m--- ---- ---- ----  ---- ---- ---- ----   m--- ---- ---- ----  ---- ---- ---- ----,
            a, 100, 0x3000,
            b, 50,  0x1000,
            e, 100, 0x2000,
            m, 100, 0x0700,
            END); */

    RESET_MEMENV3(3);
    RESET_MEMENV3(4);
    RESET_MEMENV3(5);
    RESET_MEMENV3(6);
    RESET_MEMENV3(7);
    RESET_MEMENV3(8);
    RESET_MEMENV3(9);
    RESET_MEMENV3(10);
    
    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_EA) = AR;
    
    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*2;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_ATIME) = AY0;

    jump MultiMeasureCheck;

Measure4:

/* SETTRACK(NOCLEAR, 0, 0,  ---- --x- ---- ----  ---- ---- ---- ----   ---- ---- ---- ----  ---- --x- ---- ----,
            CLEAR,   0, 7,  f--- f-a- ---- f-f-  fif- f--- g--- --ff   f--- f--- ---- fif-  f-f- f--- g-aa abcd,
            CLEAR,   0, 8,  f--- f-a- ---- f-f-  fif- f--- g--- --ff   f--- f--- ---- fif-  f-f- f--- g-aa abcd,
            a, 100, 0x0400,
            b, 100, 0x0600,
            c, 100, 0x0800,
            d, 100, 0x0a00,
            f, 100, 0x1000,
            g, 100, 0x2c00,
            i, 100, 0x0100,
            x, 50,  0x1000,
            END); */

    RESET_MEMENV3(11);
    RESET_MEMENV3(12);
    RESET_MEMENV3(13);
    RESET_MEMENV3(14);            

    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*32*2;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ATIME) = AY0;
    
    jump MultiMeasureCheck;

Measure8:

/* SETTRACK(CLEAR, 0, 1,  ---- ---- b--- ----  ---- c--- ---- ----   ---- --c- ---- ----  ---- ---- b--- ----,
            b, 100, 0x2000,
            c, 100, 0x1500,
            END); */

    RESET_MEMENV3(15);
    RESET_MEMENV3(16);

    AR = 0x7fff;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*2;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ATIME) = AY0;
    
    jump MultiMeasureCheck;

Measure12:

/* SETTRACK(CLEAR, 0, 3,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 4,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 15, ---- ---- n--- ----  ---- ---- n--- ----   ---- ---- n--- ----  ---- ---- n--- ----,
            d, 100, 0x0100,
            m, 100, 0x0700,
            n, 100, 0x0400,
            o, 100, 0x0600,
            END); */

    RESET_MEMENV3(17);
    RESET_MEMENV3(18);
    RESET_MEMENV3(19);
    RESET_MEMENV3(20);
    RESET_MEMENV3(21);
    RESET_MEMENV3(22);

    AR = 0x7fff;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*4;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_ATIME) = AY0;
    
    jump MultiMeasureCheck;

Measure20:

/* SETTRACK(NOCLEAR, 0, 5,  ---- ---- ---- ----  ---- ---- ---- --h-   ---- ---- ---- ----  ---- ---- ---- --f-,
            NOCLEAR, 0, 6,  ---- ---- ---- ----  ---- ---- ---- --h-   ---- ---- ---- ----  ---- ---- ---- --f-,
            CLEAR, 0, 9,    g--- ---- ---- ----  ---- --g- ---- ----   g--- ---- ---- ----  ---- --g- ---- ----,
            f, 100, 0x0800,
            h, 100, 0x0400,
            g, 100, 0x0a00,
            END); */

    RESET_MEMENV3(25);
    RESET_MEMENV3(26);

    AR = 0x7fff;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ATIME) = AY0;    
    
    jump MultiMeasureCheck;

Measure28:

/* SETTRACK(CLEAR, 0, 12, k--- ---- ---- ----  ---- ---- ---- ----   k--- ---- ---- ----  ---- ---- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- ---- ---- ----   l--- ---- ---- ----  ---- ---- ---- ----,
            k, 100, 0x0e00,
            l, 100, 0x0900,
            END); */
    
    RESET_MEMENV3(31);
    RESET_MEMENV3(32);
    RESET_MEMENV3(33);
    RESET_MEMENV3(34);

    AR = 0x2000;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_SA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*32*8;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_ATIME) = AY0;


    jump MultiMeasureCheck;

Measure32:
    ! unmap MemEnv3 to track volume.  mute won't work without this...
    AY0 = 0x0000;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AY0;        ! bd0
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AY0;        ! bd0
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AY0;       ! bd1
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AY0;       ! bd1
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ED) = AY0;       ! noise0
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ED) = AY0;       ! noise0
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ED) = AY0;       ! noise1
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ED) = AY0;       ! noise1
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AY0;       ! hh0
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AY0;       ! hh0
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AY0;       ! hh1
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AY0;       ! hh1
    
/* SETTRACK(CLEAR, 0, 10, h-i- i--- j--- h---  i--- i-j- h-i- --j-   h--- i--- j--- h-i-  i--- i--- h--- j-j-,
            h, 100, 0x1400,
            i, 100, 0x0c00,
            j, 100, 0x0800,
            END); */

    RESET_MEMENV3(27);
    RESET_MEMENV3(28);

    AR = 0x2000;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_SA) = AR;  
    
    AR = 0x7fff;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_ATIME) = AY0;

    /* bass code */
    RESET_MEMENV3(25);
    RESET_MEMENV3(26);

    AR = 0x4000;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_EA) = AR;
    
    AY0 = 21*64*16;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ATIME) = AY0;  
    
    jump MultiMeasureCheck;

Measure34:

/* SETTRACK(CLEAR, 0, 11, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-   h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            h, 100, 0x1400,
            i, 100, 0x0c00,
            j, 100, 0x0800,
            END); */

    RESET_MEMENV3(29);
    RESET_MEMENV3(30);

    AR = 0x2000;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_SA) = AR;  
    
    AR = 0x7fff;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_EA) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_ATIME) = AY0;

    AR = 80;
    DM(v_KeepLeadFreq0) = AR;
    
    AR = 15;
    DM(v_IncLeadFreq0) = AR;
    
    AR = 5;
    DM(v_DecLeadFreq0) = AR;

    jump MultiMeasureCheck;

Measure36:
    AR = 80;
    DM(v_KeepLeadFreq1) = AR;
    AR = 15;
    DM(v_IncLeadFreq1) = AR;
    AR = 5;
    DM(v_DecLeadFreq1) = AR;
    
    jump MultiMeasureCheck;

Measure38:
/* SETTRACK(CLEAR, 0, 12, k--- ---- ---- ----  ---- --k- ---- ----   k--- ---- ---- ----  ---- --k- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- --l- ---- ----   l--- ---- ---- ----  ---- --l- ---- ----,
            k, 100, 0x0e00,
            l, 100, 0x0900,
            END); */

    AR = 0x0003;
    DM(v_PadMask) = AR;
    jump MultiMeasureCheck;

Measure40:
/* SETTRACK(CLEAR, 0, 2,  ---- c--- ---- ----  ---- c--- ---- --c-   ---- ---- ---- c---  ---- c--- ---- ----,
            c, 100, 0x0600,
            END); */

    RESET_MEMENV3(3);
    RESET_MEMENV3(4);
    RESET_MEMENV3(15);
    RESET_MEMENV3(16);
    
    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*4;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ATIME) = AY0;
        
    jump MultiMeasureCheck;

Measure41:
    
    RESET_MEMENV3(11);
    RESET_MEMENV3(12);
    RESET_MEMENV3(13);
    RESET_MEMENV3(14);

    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AR;
    
    AY0 = 21*64*4;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ATIME) = AY0;
    
    jump MultiMeasureCheck;

Measure42:

/* SETTRACK(CLEAR, 0, 3,  --d- ---- d--- ----  d--- ---- dede dfef   --d- ---- d--- ----  dfef d--- --de d-f-,
            CLEAR, 0, 4,  --d- ---- d--- ----  d--- ---- dede dfef   --d- ---- d--- ----  dfef d--- --de d-f-,
            d, 100, 0x0100,
            e, 100, 0x0040,
            f, 100, 0x0080,
            END); */
            
    RESET_MEMENV3(17);
    RESET_MEMENV3(18);
    RESET_MEMENV3(19);
    RESET_MEMENV3(20);

    AY0 = 0x7fff;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ED) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ED) = AY0;   

    AY0 = 21*64*2;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ATIME) = AY0;
    
    jump MultiMeasureCheck;

Measure43:
/* SETTRACK(CLEAR, 0, 14, o--- ---- --m- ----  m--- ---- m--- ----   o--- ---- --m- ----  m--- ---- ---- m---,
            CLEAR, 0, 15, ---- n--- ---- p---  ---- n--- --n- ----   ---- n--- ---- n---  ---- p--- --n- ----,
            m, 100, 0x0600,
            n, 100, 0x0400,
            o, 100, 0x0a00,
            p, 100, 0x0800,
            END); */

    RESET_MEMENV3(9);
    RESET_MEMENV3(10);
    RESET_MEMENV3(21);
    RESET_MEMENV3(22);

    AY0 = 21*64*4;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_ATIME) = AY0;

    RESET_MEMENV3(37);
    RESET_MEMENV3(38);
    
    AY0 = 0x1000;
    DM(a_MemEnv3+(37*ME3_VARS)+ME3_EA) = AY0;
    DM(a_MemEnv3+(38*ME3_VARS)+ME3_EA) = AY0;
    
    DM(a_MemEnv3+(37*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(38*ME3_VARS)+ME3_ED) = AY0;

    jump MultiMeasureCheck;
    

Measure44:
/*
    RESET_MEMENV3(25);
    RESET_MEMENV3(26);
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ATIME) = AY0;  
*/  
    jump MultiMeasureCheck;

Measure48:

    AR = 0x7fff;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ED) = AR;
    
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_EA) = AR;

    jump MultiMeasureCheck;

Measure56:

/* SETTRACK(CLEAR, 0, 0,  a--- ---- ---- ----  a--- ---- ---- a---   ---- ---- a--- ----  a--- ---- ---- a---,
            CLEAR, 0, 1,  ---- ---- b--- ----  ---- ---- b--- ----   b--- ---- ---- ----  ---- ---- b--- ----,
            a, 100, 0x3000,
            b, 100, 0x2000,
            END); */

    AR = 64;
    DM(a_Seq2+1+(1*SEQ2_VARS)+SEQ2_TRIGRATE) = AR;

    jump MultiMeasureCheck;

Measure60:

/* SETTRACK(NOCLEAR, 0, 5,  ---- ---- ---- ----  --f- ---- ---- ----   ---- ---- ---- --g-  ---- ---- ---- ----,
            NOCLEAR, 0, 6,  ---- ---- ---- ----  --f- ---- ---- ----   ---- ---- ---- --g-  ---- ---- ---- ----,
            f, 100, 0x0400,
            g, 100, 0x0600,
            END); */

    jump MultiMeasureCheck;

Measure64:
    RESET_MEMENV3(3);
    RESET_MEMENV3(4);
    
    RESET_MEMENV3(15);
    RESET_MEMENV3(16);

    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_SA) = AR;
    
    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_EA) = AR;
    
    AR = 0x0000;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AR;

    AY0 = 1;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_DTIME) = AY0;

Measure66:

    RESET_MEMENV3(11);
    RESET_MEMENV3(12);
    RESET_MEMENV3(13);
    RESET_MEMENV3(14);
    RESET_MEMENV3(35);
    RESET_MEMENV3(36);

    AR = ^a_RMixScalars+2;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_ADDR) = AR;
    AR = ^a_LMixScalars+2;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_ADDR) = AR;

    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_SA) = AR;
    
    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_EA) = AR;
    
    AR = 0x0000;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_ED) = AR;

    AY0 = 1;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(35*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(36*ME3_VARS)+ME3_DTIME) = AY0;

Measure68:

    RESET_MEMENV3(25);
    RESET_MEMENV3(26);

    AR = 0x7fff;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_SA) = AR;
    
    AR = 0x7fff;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_EA) = AR;
    
    AR = 0x0000;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ED) = AR;

    AY0 = 1;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 21*64*8;
    DM(a_MemEnv3+(25*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(26*ME3_VARS)+ME3_DTIME) = AY0;
    
    jump MultiMeasureCheck;

Measure76:

    RESET_MEMENV3(27);
    RESET_MEMENV3(28);
    RESET_MEMENV3(29);
    RESET_MEMENV3(30);

    AR = 0x7fff;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_SA) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_SA) = AR;
    
    AR = 0x7fff;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_EA) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_EA) = AR;
    
    AR = 0x0000;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_ED) = AR;

    AY0 = 1;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 21*64*4;
    DM(a_MemEnv3+(27*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(28*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(29*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(30*ME3_VARS)+ME3_DTIME) = AY0;

    jump MultiMeasureCheck;


Measure80:
/* OLDTRACK(CLEAR, 0, 0,  a--- --c- ---- --c-  ---- c--- ---- a---   ---- a--- --c- ----  a--- ---- a--- c---,
            CLEAR, 0, 1,  ---- ---- b--- ----  ---- ---- b--- ----   ---- ---- b--- ----  ---- b--- ---- ----,
            a, 100, 0x3000,
            b, 100, 0x2000,
            c, 100, 0x1000,
            END); */

    RESET_MEMENV3(3);
    RESET_MEMENV3(4);                

    RESET_MEMENV3(15);
    RESET_MEMENV3(16);

    AR = 0x7fff;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AR;
    
    jump MultiMeasureCheck;

Measure82:
/* SETTRACK(CLEAR, 0, 7,  g-fa fa-- bb-b fc-c  g-f- faf- --f- f-ff   g-f- fff- f--- f---  g-ff a-fa fb-- faf-,
            CLEAR, 0, 8,  g-fa fa-- bb-b fc-c  g-f- faf- --f- f-ff   g-f- fff- f--- f---  g-ff a-fa fb-- faf-,
            f, 100, 0x1c00,
            a, 100, 0x0200,
            b, 100, 0x0300,
            c, 100, 0x400,
            g, 100, 0x3000,
            END); */

    RESET_MEMENV3(11);
    RESET_MEMENV3(12);
    RESET_MEMENV3(13);
    RESET_MEMENV3(14);    
        
    AR = 0x7fff;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AR;

    jump MultiMeasureCheck;

Measure84:
    RESET_MEMENV3(3);
    RESET_MEMENV3(4);                

    RESET_MEMENV3(15);
    RESET_MEMENV3(16);

    RESET_MEMENV3(5);
    RESET_MEMENV3(6);
    RESET_MEMENV3(7);
    RESET_MEMENV3(8);
        
    AR = 0x0000;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_ED) = AR;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_ED) = AR;

    AY0 = 1;
    DM(a_MemEnv3+(3*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(4*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(15*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(16*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(11*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(12*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(13*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(14*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_DTIME) = AY0;

    AY0 = 1;
    DM(a_MemEnv3+(5*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(6*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(7*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(8*ME3_VARS)+ME3_ATIME) = AY0;

    
    jump MultiMeasureCheck;

Measure88:

/* SETTRACK(CLEAR, 0, 12, k--- ---- ---- ----  ---- ---- ---- ----   ---- ---- ---- ----  ---- ---- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- ---- ---- ----   ---- ---- ---- ----  ---- ---- ---- ----,
            k, 100, 0x0e00,
            l, 100, 0x0900,
            END); */

    RESET_MEMENV3(17);
    RESET_MEMENV3(18);
    RESET_MEMENV3(19);
    RESET_MEMENV3(20);    
    RESET_MEMENV3(9);
    RESET_MEMENV3(10);
    RESET_MEMENV3(21);
    RESET_MEMENV3(22);
    
    AY0 = 0x0000;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ED) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ED) = AY0;   
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_ED) = AY0;    
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_ED) = AY0;   

    AY0 = 1;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 1;
    DM(a_MemEnv3+(17*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(18*ME3_VARS)+ME3_DTIME) = AY0;    
    DM(a_MemEnv3+(19*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(20*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(9*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(10*ME3_VARS)+ME3_DTIME) = AY0;    
    DM(a_MemEnv3+(21*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(22*ME3_VARS)+ME3_DTIME) = AY0;
    
    jump MultiMeasureCheck;

Measure89:
    set FL1;
    
    RESET_MEMENV3(31);
    RESET_MEMENV3(32);
    RESET_MEMENV3(33);
    RESET_MEMENV3(34);    

    AY0 = 0x0000;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_ED) = AY0;    
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_ED) = AY0;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_ED) = AY0;
    
    AY0 = 1;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_ATIME) = AY0;    
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_ATIME) = AY0;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_ATIME) = AY0;
    
    AY0 = 1;
    DM(a_MemEnv3+(31*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(32*ME3_VARS)+ME3_DTIME) = AY0;    
    DM(a_MemEnv3+(33*ME3_VARS)+ME3_DTIME) = AY0;
    DM(a_MemEnv3+(34*ME3_VARS)+ME3_DTIME) = AY0;
    
    jump MultiMeasureCheck;
    

DoNothing:
    jump MultiMeasureCheck;


/* OLDTRACK(CLEAR, 0, 0,  a--- ---- ---- ----  a--- ---- ---- a---   ---- a--- ---- ----  a--- ---- ---- a---,
            CLEAR, 0, 1,  ---- ---- b--- --b-  ---- ---- b--- ----   ---- --b- ---- --b-  ---- ---- b--- --b-,
            CLEAR, 0, 2,  ---- c--- ---- ----  ---- c--- ---- --c-   ---- ---- ---- c---  ---- c--- ---- --c-,
            CLEAR, 0, 3,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 4,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 5,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 6,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 7,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff   f-f- fff- f--- f---  f-ff --f- f-f- f-ff,
            CLEAR, 0, 8,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff   f-f- fff- f--- f---  f-ff --f- f-f- f-ff,
            CLEAR, 0, 9,  g--- ---- ---- ----  ---- --g- ---- ----   g--- ---- ---- ----  ---- --g- ---- ----,
            CLEAR, 0, 10, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-   h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 11, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-   h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 12, k--- ---- ---- ----  ---- --k- ---- ----   k--- ---- ---- ----  ---- --k- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- --l- ---- ----   l--- ---- ---- ----  ---- --l- ---- ----,
            CLEAR, 0, 14, m--- ---- --m- ----  m--- ---- m--- ----   m--- ---- --m- ----  m--- ---- ---- m---,
            CLEAR, 0, 15, ---- n--- ---- n---  ---- n--- --n- ----   ---- n--- ---- n---  ---- n--- --n- ----,
            a, 100, 0x3000,
            b, 100, 0x2000,
            c, 100, 0x0600,
            d, 100, 0x0100,
            e, 100, 0x2000,
            f, 100, 0x1800,
            g, 100, 0x0c00,
            h, 100, 0x1000,
            i, 50,  0x0c00,
            j, 20,  0x0800,
            k, 100, 0x0c00,
            l, 100, 0x0700,
            m, 100, 0x0500,
            n, 100, 0x0400,
            END); */

.ENDMOD;
