/******************************************************************************
*
*  AlgoSine.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  sine wave generated through taylor approximation
*
******************************************************************************/

.MODULE                                     modAlgoSine;

/*
 *  include files
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

/*
 *  external variables
 */


/*
 *  entry points
 */

.ENTRY      AlgoSineGen;

/*
 *  sin_coeff[0]:  as it increases, turns sine into square
 *                 as it decreases, get a dip at peak (mcdonalds), lose amp
 *  sin_coeff[1]:  as it increases, turns sine into square
 *  sin_coeff[2]:  as it increases, turns sine into square
 *  sin_coeff[3]:  as it increases, turns sine into square
 *  sin_coeff[4]:  as it increases, turns sine into square
 *                 as it decreases, get a dip at peak (mcdonalds)
 *
 *  as go further into array, effects are less dramatic
 *
 *  moving one up and another down leads to triangle wave, exponential looking
 *  thingy and then full scale square wave.
 *
 *  nb:  the reason the weird saturation occurs as the polynomials get more
 *  messed up is because MR1 eventually becomes > 0x2000 at the end end of
 *  the SA loop.  then when the shift/saturation check happens SR1 is tiny
 *  (the sign bit is shifted out of sight) and we're left with a really
 *  small number.  why can't we do a saturating shift?!?!  remedy would be
 *  to check MR1 and see if it's > 0x1fff.  if so, clamp it there.
 */

AlgoSineGen:
    I2 = DM(p_AlgoSineGen);
    dis AR_SAT;
    AX0 = DM(I2, M1);                       /* phase accumulator */
    AY0 = DM(I2, M0);                       /* current phase */
    AR = AX0 + AY0;
    DM(I2, M1) = AR;                        /* newphase=currphase+phaseacc */
    ena AR_SAT;
    AX0 = AR;
    AF = AX0 and 0x4000;                    /* Check 2nd or 4th quad */
    if NE AR=-AX0;                          /* If yes, negate input */
    AR = AR and 0x7fff;                     /* remove sign bit */
    MY1 = AR;
    MF=AR*MY1 (RND), MX1=DM(I2,M1);         /* MF = x**2 */
    MR=MX1*MY1 (SS), MX1=DM(I2,M1);         /* MR = C1*x */
    CNTR = 3;
    do SA until CE;
      MR = MR + MX1 * MF (SS);
SA:   MF=AR*MF (RND), MX1=DM(I2,M1);
    MR = MR + MX1 * MF (SS);
    SR = ashift MR1 by 3 (HI);
    SR = SR or lshift MR0 by 3 (LO);        /* Convert to 1.15 format */
    AR = pass SR1;
    if LT AR = pass 0x7fff;                 /* Saturate if needed */
    AF = pass AX0;
    if LT AR = -AR;                         /* Negate output if needed */
    DM(I7, M6) = AR;
    DM(p_AlgoSineGen) = I2;
    rts;
    
.ENDMOD;

