/******************************************************************************
*
*  GenFXVars.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  variables for generators & effects + syssetup vars 
*
******************************************************************************/

.MODULE                                     modGenFXVar;

/* force exclusion of .EXTERNALs to avoid mass warnings */
#define     GENFXVAR_FUNC


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

/******************************************************************************
*  
*  repository for outputs of generators.  from here, data is passed into
*  the LSamp and RSamp arrays via the pan function.
*
*******************************************************************************/

.VAR/DM         a_GenData[MAXTRACKS];
.GLOBAL         a_GenData;
                                          
.VAR/DM         p_GenData;
.GLOBAL         p_GenData;

.VAR/DM         a_RMixScalars[MAXTRACKS];
.GLOBAL         a_RMixScalars;

.VAR/DM         a_LMixScalars[MAXTRACKS];
.GLOBAL         a_LMixScalars;

.VAR/DM         a_TempRMixScalars[MAXTRACKS];
.GLOBAL         a_TempRMixScalars;

.VAR/DM         a_TempLMixScalars[MAXTRACKS];
.GLOBAL         a_TempLMixScalars;

/******************************************************************************
*  
*  holds outputs of all signal generators for a single sample.  these are
*  summed and placed in the LOutBuff & ROutBuff arrays and from there are
*  written to the serial port TX buffer.
*
*******************************************************************************/

.VAR/DM/CIRC    a_LSampOut[MAXTRACKS];
.GLOBAL         a_LSampOut;

.VAR/DM/CIRC    a_RSampOut[MAXTRACKS];
.GLOBAL         a_RSampOut;

/******************************************************************************
*
*  Output PingPong Arrays.  while Buff0 is filled with data, Buff1 is written
*  to the serial port TX registers and vice versa.  two sets of pointers are 
*  also provided which address locations within these arrays.  one set is 
*  designated for the SPORT TX routines (p_LBuffToTX) and another pointer to
*  the array written to in gmInit (OutBuff).  note how these are init'ed to
*  opposite buffers to get the pingpong process started.
*
******************************************************************************/

.VAR/DM/CIRC    a_LOutBuff0[OUTBUFFLEN];
.GLOBAL         a_LOutBuff0;

.VAR/DM/CIRC    a_ROutBuff0[OUTBUFFLEN];
.GLOBAL         a_ROutBuff0;

.VAR/DM/CIRC    a_LOutBuff1[OUTBUFFLEN];
.GLOBAL         a_LOutBuff1;

.VAR/DM/CIRC    a_ROutBuff1[OUTBUFFLEN];
.GLOBAL         a_ROutBuff1;

.VAR/DM         p_LBuffToTX;
.GLOBAL         p_LBuffToTX;
.INIT           p_LBuffToTX:                ^a_LOutBuff1;

.VAR/DM         p_RBuffToTX;
.GLOBAL         p_RBuffToTX;
.INIT           p_RBuffToTX:                ^a_ROutBuff1;

.VAR/DM         p_LOutBuff;
.GLOBAL         p_LOutBuff;
.INIT           p_LOutBuff:                 ^a_LOutBuff0;

.VAR/DM         p_ROutBuff;
.GLOBAL         p_ROutBuff;
.INIT           p_ROutBuff:                 ^a_ROutBuff0;

.VAR/DM/CIRC    a_LAudioInBuff[128];
.GLOBAL         a_LAudioInBuff;

.VAR/DM         p_LInAudioInBuff;
.GLOBAL         p_LInAudioInBuff;

.VAR/DM         p_LOutAudioInBuff;
.GLOBAL         p_LOutAudioInBuff;

.VAR/DM/CIRC    a_RAudioInBuff[128];
.GLOBAL         a_RAudioInBuff;

.VAR/DM         p_RInAudioInBuff;
.GLOBAL         p_RInAudioInBuff;

.VAR/DM         p_ROutAudioInBuff;
.GLOBAL         p_ROutAudioInBuff;

/******************************************************************************
*  
*  ClampFX Variables
*
*  one variable consumed per call
*  ten calls allowed
*
*******************************************************************************/

.VAR/DM         a_ClampFX[CLAMPFX_VARS*CLAMPFX_CALLS];
.GLOBAL         a_ClampFX;

.VAR/DM         p_ClampFX;
.GLOBAL         p_ClampFX;


/******************************************************************************
*  
*  ZeroSampsFX Variables
*
*  one variable consumed per call
*  ten calls allowed
*
*******************************************************************************/

.VAR/DM         a_ZeroSampsFX[ZEROSAMPSFX_VARS*ZEROSAMPSFX_CALLS];
.GLOBAL         a_ZeroSampsFX;

.VAR/DM         p_ZeroSampsFX;
.GLOBAL         p_ZeroSampsFX;


/******************************************************************************
*  
*  Rotation Synth Variables
*
*******************************************************************************/

.VAR/DM         a_RotSynthGen[ROTSYNTHGEN_VARS*ROTSYNTHGEN_CALLS];
.GLOBAL         a_RotSynthGen;

.VAR/DM         p_RotSynthGen;
.GLOBAL         p_RotSynthGen;

/******************************************************************************
*  
*  Tuned Rotation Synth Variables
*
*******************************************************************************/

.VAR/DM         a_TunedRotSynthGen[TUNEDROTSYNTHGEN_VARS*TUNEDROTSYNTHGEN_CALLS];
.GLOBAL         a_TunedRotSynthGen;

.VAR/DM         p_TunedRotSynthGen;
.GLOBAL         p_TunedRotSynthGen;

/******************************************************************************
*  
*  FM Synthesis Variables
*
*******************************************************************************/

.VAR/DM         a_FM2Op0Gen[FM2OP0_VARS*FM2OP0_CALLS];
.GLOBAL         a_FM2Op0Gen;

.VAR/DM         p_FM2Op0Gen;
.GLOBAL         p_FM2Op0Gen;


/******************************************************************************
*  
*  Probability Synth Variables
*
*  ProbSyn rotation frequency
*  ProbSyn count
*  ProbSyn current value
*  ProbSyn MSB probability to LSB probability (bit15-bit8)
*
*******************************************************************************/

.VAR/DM         a_ProbSynthGen[PROBSYNTHGEN_VARS*PROBSYNTHGEN_CALLS];
.GLOBAL         a_ProbSynthGen;

.VAR/DM         p_ProbSynthGen;
.GLOBAL         p_ProbSynthGen;

.VAR            a_ProbSynthGenMask[8];
.GLOBAL         a_ProbSynthGenMask;
.INIT           a_ProbSynthGenMask:

    0x8000, 0x4000, 0x2000, 0x1000, 0x0800, 0x0400, 0x0200, 0x0100;

/******************************************************************************
*  
*  Periodic Noise Generation Variables
*
*  one variable consumed per call
*  20 call allowed
*
*   LSW of 32bit seed
*
*******************************************************************************/

.VAR/DM         a_PerNoiseGen[PERNOISEGEN_VARS*PERNOISEGEN_CALLS];
.GLOBAL         a_PerNoiseGen;

.VAR/DM         p_PerNoiseGen;
.GLOBAL         p_PerNoiseGen;

.VAR/DM/CIRC    a_PerNoiseGenParam[19];
.GLOBAL         a_PerNoiseGenParam;
.INIT           a_PerNoiseGenParam:
/*
    15, 17, 31, 33, 39,  47, 63, 65, 79, 95,  111, 127, 129, 137, 159,
    161, 175, 191, 197;
*/
/*
    15, 17, 31, 33, 47, 49, 63, 65,
    79, 71, 95, 97, 111, 113, 127, 129,
    143, 145, 159;
*/

    191, 95, 31, 159, 63,  65, 127, 129, 255, 257,  511, 513, 1023, 1025, 2047,
    2049, 4095, 4097, 8191;

/******************************************************************************
*  
*  Karplus Strong Generation Variables
*
*  five variables consumed per call
*  five calls allowed
*
*  KSMode
*    b0:  add (1) or subtract (0) adjacent samples
*  pointer into delay line
*  virtual length of delay line, determines freq of output.
*  threshold determining if averaging factor is negated.  range 0xc000-0x3fff.
*    if random number > thresh
*      output = (ave factor)*(input(n) +/- input(n-1))
*    if random number < thresh
*      output = -(ave factor)*(input(n) +/- input(n-1))
*  averaging factor.  to maintain stability, keep at +/-0.5  0xc000 creates
*    output = -0.5(input(n) +/- input(n-1)), which has interesting harmonics
*
*  examples for KSParams:
*    0x0001 - add adj samples
*    0x0300 - ptr into delay line
*    0x0100 - virtual len of delay line, freq=(44100/256)Hz
*    0xc000 - rand always > thresh, never negate ave factor
*    0x4000 - averaging factor = 0.5
*
*       output = 0.5*(input(n)+input(n-1)) always
*       sounds like the normal plucked string
*
*    0x0001 - add adj samples
*    0x0500 - ptr into delay line
*    0x0040 - virtual len of delay line, freq=(44100/64)Hz
*    0x0000 - equal chance of + or - ave factor
*    0x4000 - averaging factor = 0.5
*
*       output = 0.5*(input(n)+input(n-1)) 50%
*       output = -0.5*(input(n)+input(n-1)) 50%
*       sounds like a decimated drum.
*
*    0x0000 - sub adj samples
*    0x0500 - ptr into delay line
*    0x0080 - virtual len of delay line, freq=(44100/128)Hz
*    0x3fff - always neg ave factor
*    0x4000 - averaging factor = 0.5
*
*       output = -0.5*(input(n)+input(n-1)) always
*       sounds like plucked string, different harmonic content
*
*    notes:
*       - subtracting samples leads to a real fast HP filter.  seems to only
*         be good for small drum sounds, maybe a high ave factor would make it
*         more interesting
*       - decoupling freq of tone by length of buffer not implemented.  to
*         create the random number for test, be sure to seed the RNG with new
*         values, maybe from the timer
*
*   droning high freq thing.  what if this were gated to create rhythm?
*
*   DM(I2, M1) = 0x0001;   
*   DM(I2, M1) = ^a_KSBuff1
*   DM(I2, M1) = 0x1ff;    
*   DM(I2, M1) = 0x0000;   
*   DM(I2, M1) = 0x5c00;
*  
*       - try setting the 4th parameter to something close to 0x4000/0xc000.
*         you get (65536/44100)*|diff from 0x4000| ticks/sec.  free rhythm!
*
*   droning low freq thing w/ cool overtones that eventually gets some ticking
*   thrown in just for fun:
*
*   DM(I2, M1) = 0x0001;                   
*   DM(I2, M1) = ^a_KSBuff1;                
*   DM(I2, M1) = 0x1ff;                     
*   DM(I2, M1) = 0xc000;                    
*   DM(I2, M1) = 0x4008;                    

*   DM(I2, M1) = 0x0001;                    
*   DM(I2, M1) = ^a_KSBuff2;                
*   DM(I2, M1) = 0x1f1;                     
*   DM(I2, M1) = 0xc000;                    
*   DM(I2, M1) = 0x4008;                    
*
*   the ticking may be due to poorly handled saturation, so it may (selectively)
*   go away.
*
*******************************************************************************/

.VAR/DM         a_KSGen[KSGEN_VARS*KSGEN_CALLS];
.GLOBAL         a_KSGen;

.VAR/DM         p_KSGen;
.GLOBAL         p_KSGen;

.VAR/DM         a_ProbKSGen[PROBKSGEN_VARS*PROBKSGEN_CALLS];
.GLOBAL         a_ProbKSGen;

.VAR/DM         p_ProbKSGen;
.GLOBAL         p_ProbKSGen;

/******************************************************************************
*  
*  multi-tap delay line synth, similar to KSGen
*
*******************************************************************************/

.VAR/DM         a_DelaySynthGen[DELAYSYNTHGEN_VARS*DELAYSYNTHGEN_CALLS];
.GLOBAL         a_DelaySynthGen;

.VAR/DM         p_DelaySynthGen;
.GLOBAL         p_DelaySynthGen;

/******************************************************************************
*  
*  audio rate sample/hold FX
*
*******************************************************************************/

.VAR/DM         a_GenSHFX[GENSHFX_VARS*GENSHFX_CALLS];
.GLOBAL         a_GenSHFX;

.VAR/DM         p_GenSHFX;
.GLOBAL         p_GenSHFX;

/******************************************************************************
*  
*  generator which copies output of one generator into another (pre env)
*
*******************************************************************************/

.VAR/DM         a_CopiedGen[COPIEDGEN_VARS*COPIEDGEN_CALLS];
.GLOBAL         a_CopiedGen;

.VAR/DM         p_CopiedGen;
.GLOBAL         p_CopiedGen;

/******************************************************************************
*  
*  oscillator sync for WTGen/WTGen2
*
*******************************************************************************/

.VAR/DM         a_WTGenSyncFX[WTGENSYNCFX_VARS*WTGENSYNCFX_CALLS];
.GLOBAL         a_WTGenSyncFX;

.VAR/DM         p_WTGenSyncFX;
.GLOBAL         p_WTGenSyncFX;

/******************************************************************************
*  
*  generator waveshaper
*
*******************************************************************************/

.VAR/DM         a_WaveShapeFX[WAVESHAPEFX_VARS*WAVESHAPEFX_CALLS];
.GLOBAL         a_WaveShapeFX;

.VAR/DM         p_WaveShapeFX;
.GLOBAL         p_WaveShapeFX;

/******************************************************************************
*  
*  exponential impulse generator
*
*******************************************************************************/

.VAR/DM         a_ExpImpulseGen[EXPIMPULSEGEN_VARS*EXPIMPULSEGEN_CALLS];
.GLOBAL         a_ExpImpulseGen;

.VAR/DM         p_ExpImpulseGen;
.GLOBAL         p_ExpImpulseGen;

/******************************************************************************
*  
*  multiple generators through single envelope
*
*******************************************************************************/

.VAR/DM         a_MultiGen[MULTIGEN_VARS];
.GLOBAL         a_MultiGen;

.VAR/DM         p_MultiGen;
.GLOBAL         p_MultiGen;

/******************************************************************************
*  
*  random number array for filling KS buffer and other misc random number
*  duties
*
*******************************************************************************/

.VAR/DM/CIRC    a_RandLUT[RANDLEN];
.GLOBAL         a_RandLUT;


/******************************************************************************
*  
*  various memory envelope functions/arrays
*
*******************************************************************************/

.VAR/DM         a_MemEnv1[ME1_VARS*ME1_CALLS];
.GLOBAL         a_MemEnv1;

.VAR/DM         p_MemEnv1;
.GLOBAL         p_MemEnv1;

.VAR/DM         v_NumMemEnv1;
.GLOBAL         v_NumMemEnv1;

.VAR/DM         a_MemEnv2[ME2_VARS*ME2_CALLS];
.GLOBAL         a_MemEnv2;

.VAR/DM         p_MemEnv2;
.GLOBAL         p_MemEnv2;

.VAR/DM         v_NumMemEnv2;
.GLOBAL         v_NumMemEnv2;

.VAR/DM         a_MemEnv3[ME3_VARS*ME3_CALLS];
.GLOBAL         a_MemEnv3;

.VAR/DM         p_MemEnv3;
.GLOBAL         p_MemEnv3;

.VAR/DM         v_NumMemEnv3;
.GLOBAL         v_NumMemEnv3;

/******************************************************************************
*  
*  exponential decay envelope
*
*  decay factor
*  current decay amount
*  
*  newdecay = olddecay*decayfactor
*  olddecay = newdecay
*
*******************************************************************************/

.VAR/DM         a_ExpDecayEnv[EXPDECAYENV_VARS*EXPDECAYENV_CALLS];
.GLOBAL         a_ExpDecayEnv;

.VAR/DM         p_ExpDecayEnv;
.GLOBAL         p_ExpDecayEnv;

/******************************************************************************
*  
*  generic wavetable synth with linear interpolation
*
*******************************************************************************/

.VAR/DM         a_WTGen[WTGEN_VARS*WTGEN_CALLS];
.GLOBAL         a_WTGen;

.VAR/DM         p_WTGen;
.GLOBAL         p_WTGen;

.VAR/DM         a_WTGen2[WTGEN2_VARS*WTGEN2_CALLS];
.GLOBAL         a_WTGen2;

.VAR/DM         p_WTGen2;
.GLOBAL         p_WTGen2;

.VAR/DM         a_HPWTGen2[HPWTGEN2_VARS*HPWTGEN2_CALLS];
.GLOBAL         a_HPWTGen2;

.VAR/DM         p_HPWTGen2;
.GLOBAL         p_HPWTGen2;

.VAR/DM/CIRC    a_WTTri[129];
.GLOBAL         a_WTTri;
#ifdef VDSP_BUILD
.INIT           a_WTTri:                    <.\gen_fx\WTtri_vdsp.hex>;
#else
.INIT           a_WTTri:                    <.\gen_fx\WTtri_legacy.hex>;
#endif

.VAR/DM/CIRC    a_WTSq[129];
.GLOBAL         a_WTSq;
#ifdef VDSP_BUILD
.INIT           a_WTSq:                     <.\gen_fx\WTsq_vdsp.hex>;
#else
.INIT           a_WTSq:                     <.\gen_fx\WTsq_legacy.hex>;
#endif

.VAR/DM/CIRC    a_WTSaw[129];
.GLOBAL         a_WTSaw;
#ifdef VDSP_BUILD
.INIT           a_WTSaw:                    <.\gen_fx\WTsaw_vdsp.hex>;
#else
.INIT           a_WTSaw:                    <.\gen_fx\WTsaw_legacy.hex>;
#endif

.VAR/DM/CIRC    a_WTSine[129];
.GLOBAL         a_WTSine;
#ifdef VDSP_BUILD
.INIT           a_WTSine:                   <.\gen_fx\WTsine_vdsp.hex>;
#else
.INIT           a_WTSine:                   <.\gen_fx\WTsine_legacy.hex>;
#endif

/******************************************************************************
*  
*  LFO function - uses wavetables
*
*******************************************************************************/

.VAR/DM         a_LFO3[LFO3_VARS*LFO3_CALLS];
.GLOBAL         a_LFO3;

.VAR/DM         p_LFO3;
.GLOBAL         p_LFO3;

.VAR/DM         v_NumLFO3;
.GLOBAL         v_NumLFO3;


/******************************************************************************
*  
*  maximum distance filter - control maximum difference between consecutive
*  samples to create a simple, easily controlled LPF
*
*******************************************************************************/

.VAR/DM         a_PrevCurrFiltFX[PREVCURRFILTFX_VARS*PREVCURRFILTFX_CALLS];
.GLOBAL         a_PrevCurrFiltFX;

.VAR/DM         p_PrevCurrFiltFX;
.GLOBAL         p_PrevCurrFiltFX;

/******************************************************************************
*
*  General Purpose Oscillator Combiner
*
*  two variables per call
*
*    0x0000:  FMMod
*    0x0001:  LoFiFMMod
*    0x0002:  xor
*    0x0003:  and
*    0x0004:  or
*    0x0005:  subtract
*
*    0x0000:  no modulation, return signals back to output array untouched
*    0x7fff:  all modulation, remove original signals
*
******************************************************************************/
     
.VAR/DM         a_OscCombGen[OSCCOMBGEN_VARS*OSCCOMBGEN_CALLS];
.GLOBAL         a_OscCombGen;
                
.VAR/DM         p_OscCombGen;
.GLOBAL         p_OscCombGen;
     
/******************************************************************************
*  
*  Noise Generation Variables
*
*  v_MSWSeed
*  v_LSWSeed
*
*  no need for pointers to these variables, automatically updated in
*  NoiseGen
*
*******************************************************************************/

.VAR/DM         v_MSWSeed;
.GLOBAL         v_MSWSeed;
.INIT           v_MSWSeed:                  0xdead;

.VAR/DM         v_LSWSeed;
.GLOBAL         v_LSWSeed;
.INIT           v_LSWSeed:                  0x0001;


/******************************************************************************
*  
*  pos or neg rectify of output
*
*******************************************************************************/

.VAR/DM         a_RectifyFX[RECTIFYFX_VARS*RECTIFYFX_VARS];
.GLOBAL         a_RectifyFX;

.VAR/DM         p_RectifyFX;
.GLOBAL         p_RectifyFX;

/******************************************************************************
*  
*  MIDI table of frequencies for "normal" sig gens and delay line based sig
*  gens.  of course LENKSBUFFx must be greater than the delay line length
*  called for in the MIDI table for the function to work.
*
*  a_MIDIFreq[128]
*  a_MIDIFreqKS[128]
*
*******************************************************************************/

.VAR/DM         a_MIDIFreq[128];
.GLOBAL         a_MIDIFreq;
.INIT           a_MIDIFreq:                 8, 9, 9, 10, 10, 11, 12, 12, 13, 14,
                                            15, 15,
                                            
                                            16, 17, 18, 19, 21, 22, 23, 24, 26,
                                            28, 29, 31,
                                            
                                            33, 35, 37, 39, 41, 44, 46, 49, 52,
                                            55, 58, 62,
                                            
                                            65, 69, 73, 78, 82, 87, 92, 98, 104,
                                            110, 117, 123,
                                            
                                            131, 139, 147, 156, 165, 175, 185,
                                            196, 208, 220, 233, 247,

                                            262, 277, 294, 311, 330, 349, 370,
                                            392, 415, 440, 466, 494,
                                            
                                            523, 554, 587, 622, 659, 698, 740,
                                            784, 831, 880, 932, 988,

                                            1047, 1109, 1175, 1245, 1319, 1397,
                                            1480, 1568, 1661, 1760, 1865, 1976,

                                            2093, 2218, 2349, 2489, 2637, 2794,
                                            2960, 3136, 3322, 3520, 3729, 3951,
                                            
                                            4186, 4435, 4699, 4978, 5274, 5588,
                                            5920, 6272, 6645, 7040, 7495, 7902,
                                            
                                            8372, 8870, 9397, 9956, 10548,
                                            11175, 11840, 12544;

.VAR/DM         a_MIDIFreqKS[128];
.GLOBAL         a_MIDIFreqKS;
.INIT           a_MIDIFreqKS:               5394, 5091, 4805, 4536, 4281, 4041,
                                            3814, 3600, 3398, 3207, 3027, 2857,
                                            
                                            2697, 2546, 2403, 2268, 2141, 2021,
                                            1907, 1800, 1699, 1604, 1514, 1429,
                                            
                                            1349, 1273, 1201, 1134, 1070, 1010,
                                            954, 900, 849, 802, 757, 714,
                                            
                                            674, 636, 601, 567, 535, 505, 477,
                                            450, 425, 401, 378, 357,
                                            
                                            337, 318, 300, 283, 268, 253, 238,
                                            225, 212, 200, 189, 179,
                                            
                                            169, 159, 150, 142, 134, 126, 119,
                                            113, 106, 100, 95, 89,
                                            
                                            84, 80, 75, 71, 67, 63, 60, 56, 53,
                                            50, 47, 45,
                                            
                                            42, 40, 38, 35, 33, 32, 30, 28, 27,
                                            25, 24, 22,
                                            
                                            21, 20, 19, 18, 17, 16, 15, 14, 13,
                                            13, 12, 11,
                                            
                                            11, 10, 9, 9, 8, 8, 7, 7, 7, 6, 6,
                                            6,
                                            
                                            5, 5, 5, 4, 4, 4, 4, 4;

/******************************************************************************
*
*  ADSRPanEnv function
*
*  ADSR update rate
*  current ADSR update rate count
*  current scalar
*  current ADSR stage
*  attack rate
*  decay rate
*  decay min
*  sustain len
*  current sustain
*  release rate
*  scalar
*  pan (0x0000=L, 0x4000=center, 0x7fff=R)
*
*******************************************************************************/

.VAR/DM         a_ADSRPanEnv[ADSRPANENV_VARS*ADSRPANENV_CALLS];
.GLOBAL         a_ADSRPanEnv;
                
.VAR/DM         p_ADSRPanEnv;
.GLOBAL         p_ADSRPanEnv;


/******************************************************************************
*
*  SVF variables
*
*******************************************************************************/

.VAR/DM         a_SVFFX[SVFFX_VARS*SVFFX_CALLS];
.GLOBAL         a_SVFFX;
                
.VAR/DM         p_SVFFX;
.GLOBAL         p_SVFFX;

.VAR/DM         a_SVFFiltOut[SVFFILTOUTVARS*SVFFILTOUTCALLS];
.GLOBAL         a_SVFFiltOut;
                
.VAR/DM         p_SVFFiltOut;
.GLOBAL         p_SVFFiltOut;


/******************************************************************************
*
*  KillTime function
*
*******************************************************************************/

.VAR/DM         a_KillTimeFX[KILLTIMEFX_VARS*KILLTIMEFX_CALLS];
.GLOBAL         a_KillTimeFX;
                
.VAR/DM         p_KillTimeFX;
.GLOBAL         p_KillTimeFX;


/******************************************************************************
*
*  KillTime function
*
*******************************************************************************/

.VAR/DM         a_BitMaskFX[BITMASKFX_VARS*BITMASKFX_CALLS];
.GLOBAL         a_BitMaskFX;
                
.VAR/DM         p_BitMaskFX;
.GLOBAL         p_BitMaskFX;

/******************************************************************************
*
*  Exp1 function
*
*******************************************************************************/

.VAR/DM         a_Exp1Gen[EXP1GEN_VARS*EXP1GEN_CALLS];
.GLOBAL         a_Exp1Gen;

.VAR/DM         p_Exp1Gen;
.GLOBAL         p_Exp1Gen;


/******************************************************************************
*
*  Sine Wave generated through taylor series
*
*******************************************************************************/

.VAR/DM         a_AlgoSineGen[ALGOSINEGEN_VARS*ALGOSINEGEN_CALLS];
.GLOBAL         a_AlgoSineGen;

.VAR/DM         p_AlgoSineGen;
.GLOBAL         p_AlgoSineGen;

.VAR/DM         a_AlgoSineSatGen[ALGOSINESATGEN_VARS*ALGOSINESATGEN_CALLS];
.GLOBAL         a_AlgoSineSatGen;

.VAR/DM         p_AlgoSineSatGen;
.GLOBAL         p_AlgoSineSatGen;

.VAR/DM         a_AlgoSineCoeff[5];
.GLOBAL         a_AlgoSineCoeff;
.INIT           a_AlgoSineCoeff:            0x3240,
                                            0x0053,
                                            0xAACC,
                                            0x08B7,
                                            0x1CCE;

/******************************************************************************
*
*  simple synthesizer
*
*******************************************************************************/

.VAR/DM         a_GenFXPtrInits[ALLGENFX*2+1];
.GLOBAL         a_GenFXPtrInits;

.VAR/DM         p_GenFXPtrInits;
.GLOBAL         p_GenFXPtrInits;

.VAR/DM         a_EnvTypes[NUMENVTYPES];
.GLOBAL         a_EnvTypes;

/******************************************************************************
*
*  arrays for all the audio channels - must be init'ed in the specific gm
*
*******************************************************************************/

.VAR/DM         a_Seq2[1+MAXTRACKS*SEQ2_VARS];
.GLOBAL         a_Seq2;

.VAR/DM         p_Vol;
.GLOBAL         p_Vol;

.VAR/DM         v_TrigOffset;
.GLOBAL         v_TrigOffset;

.VAR/DM         a_CTRLData[8];
.GLOBAL         a_CTRLData;

.VAR/DM         p_CTRLData;
.GLOBAL         p_CTRLData;

.VAR/DM         a_TrackTriggered[2];
.GLOBAL         a_TrackTriggered;

/*******************************************************************************
*
*  pointers to functions required for each song and other song related vars
*
*******************************************************************************/

.VAR/DM     InitGMParamsPtr;
.GLOBAL     InitGMParamsPtr;

.VAR/DM     GenFXPtr;
.GLOBAL     GenFXPtr;

.VAR/DM     SetFABCNTRPtr;
.GLOBAL     SetFABCNTRPtr;

.VAR/DM     ModFuncsPtr;
.GLOBAL     ModFuncsPtr;

.VAR/DM     MixerProcPtr;
.GLOBAL     MixerProcPtr;

.VAR/DM     v_LChanOut;
.GLOBAL     v_LChanOut;

.VAR/DM     v_RChanOut;
.GLOBAL     v_RChanOut;

.VAR/DM     EnvProcPtr;
.GLOBAL     EnvProcPtr;

.VAR/DM     v_CurrSong;
.GLOBAL     v_CurrSong;
.INIT       v_CurrSong:                     0;

.VAR/DM     v_NextSong;
.GLOBAL     v_NextSong;
.INIT       v_NextSong:                     0;

.VAR/DM     v_FABCNTR;
.GLOBAL     v_FABCNTR;


/*******************************************************************************
*
*  dummy variable, useful for initing memenv and LFO functions such that they
*  don't affect real data
*
*******************************************************************************/

.VAR/DM     v_Dummy;
.GLOBAL     v_Dummy;


/*******************************************************************************
*
*  variables needed for controlling song control
*
*******************************************************************************/

.VAR/DM     v_CurrMeasure;
.GLOBAL     v_CurrMeasure;

.VAR/DM     v_TicsPerMeasure;
.GLOBAL     v_TicsPerMeasure;

.VAR/DM     v_TicCNTR;
.GLOBAL     v_TicCNTR;

.VAR/DM     v_MeasuresPerSong;
.GLOBAL     v_MeasuresPerSong;

.ENDMOD; 