/******************************************************************************
*
*  WTGen.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*
******************************************************************************/

.MODULE                                     modWTGen;

/*
 *  include files
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

#define     WTLUTINTERP                 95

/*
 *  entry points
 */

.ENTRY      WTGen;

/*
 *  algorithm for linear interpolation from 128pt sine LUT is as follows:
 *
 *  1.  fetch current numerator (starts at zero)
 *  2.  add desired freq to numerator
 *  3.  divide numerator by denominator.
 *  4.  check if result is > 512.  if true, subtract 512.
 *  5.  use whole part of result as a modifier into LUT.  get LUT value at this
 *      location, and the value one location further down the LUT
 *  6.  multiply remainer by 95.  this is approximately the normalization factor
 *      required to generate interpolated result.
 *  7.  calculate [LUT(n+1)-LUT(n)]*interp.  add result to LUT(n).  note that
 *      the interpolated value could be negative depending on the direction
 *      of the sine wave.
 */

WTGen:
    I2 = DM(p_WTGen);
    AR = DM(I2, M1);                        /* get current numerator */
    AY0 = DM(I2, M1);                       /* get freq */
    dis AR_SAT;
    AR = AR + AY0;
    SR = lshift AR by -1 (lo);
    AY1 = 22050;
    AF = SR0 - AY1;
    if LE jump NoScale;
    
ScaleBack:
    AR = AR - AY1;
    AR = AR - AY1;
    
NoScale:
    ena AR_SAT;
    I3 = DM(p_WTGen);
    DM(I3, M0) = AR;                        /* write new numerator to mem */

    /* calculate offset in sine LUT */
    MY0 = WTLUTINTERP;
    MR = AR * MY0 (uu);                     /* MR1=step, MR0=interp */

    M3 = MR1;
    AX1 = DM(I2, M1);                       /* get ptr to start of WT */
    I3 = AX1;
    L3 = 128;                               /* all WT are 128 samples in len */
    modify (I3, M3);
    AY0 = DM(I3, M1);                       /* get val at LUT offset */
    AX0 = DM(I3, M1);                       /* get next value in LUT */
    AR = AX0 - AY0;                         /* LUT(n+1)-LUT(n) */

    SR = lshift MR0 by -1 (lo);             /* shift down for fract mult */    
    MY0 = AR;
    MR = SR0 * MY0 (us);                    /* scale to interpolate */
    
    AR = MR1 + AY0;                         /* AR = interpolated sine output */

    DM(I7, M6) = AR;                        /* write to output array */
    
EndWTGen:
    L3 = 0;
    DM(p_WTGen) = I2;
    
    rts;
    
.ENDMOD;